=======
Credits
=======

Development Lead (Quantmetry Team support Maif Team)
----------------------------------------------------

* Sacha Samama <ssamama@quantmetry.com>
* Tom Stringer <tstringer@quantmetry.com>
* Antoine Simoulin <asimoulin@quantmetry.com>
* Benoit Lebreton <blebreton@quantmetry.com>

Contributors
------------

None yet. Why not be the first?
